@@ -1,6 +1,6 @@
 /*
  * The GGZ Gaming Zone Metaserver Project
- * Copyright (C) 2001 - 2003 Josef Spillner, josef@ggzgamingzone.org
+ * Copyright (C) 2001 - 2006 Josef Spillner <josef@ggzgamingzone.org>
  * Published under GNU GPL conditions.
  */
 
@@ -10,11 +10,8 @@
 /* Log to the logfile if logging is enabled */
 void logline(const char *fmt, ...);
 
-/* Return the host part of an URI */
-char *meta_uri_host_internal(const char *uri);
-
-/* Return the port part of an URI */
-int meta_uri_port_internal(const char *uri);
+/* Duplicate a string, doing xml-quoting if necessary */
+char *xml_strdup(const char *s, int attribute, int url);
 
 #endif
 
